=== modified file '.bzrignore'
--- .bzrignore	2011-02-13 19:41:05 +0000
+++ .bzrignore	2011-02-22 04:19:44 +0000
@@ -345,3 +345,6 @@
 drizzled/message/catalog.pb.h
 drizzled/message/catalog_reader
 drizzled/message/catalog_writer
+drizzled/message/replication_options.pb.cc
+drizzled/message/replication_options.pb.h
+libdrizzle/mysql_password_hash

=== modified file 'drizzled/definitions.h'
--- drizzled/definitions.h	2011-02-18 22:34:55 +0000
+++ drizzled/definitions.h	2011-02-22 04:19:44 +0000
@@ -402,12 +402,6 @@
   if (a > b)
     a=b;
 }
-
-template<class T> inline void safe_delete(T*& ptr)
-{
-  delete ptr;
-  ptr = 0;
-}
 #else
 #ifdef __GNUC__
 #define set_if_bigger(a,b) do {                 \
@@ -429,6 +423,11 @@
 #endif
 #endif
 
+template<class T> inline void safe_delete(T*& ptr)
+{
+  delete ptr;
+  ptr = 0;
+}
 
 #define array_elements(a) \
   ((sizeof(a) / sizeof(*(a))) / \

=== modified file 'drizzled/message.h'
--- drizzled/message.h	2011-02-17 00:14:13 +0000
+++ drizzled/message.h	2011-02-22 04:19:44 +0000
@@ -47,6 +47,31 @@
 const std::string &type(drizzled::message::Table::ForeignKeyConstraint::ForeignKeyMatchOption type);
 const std::string &type(drizzled::message::Table::TableType type);
 
+template<class T> inline bool is_replicated(const T& reference)
+{
+  if (reference.has_replication_options() and
+      reference.replication_options().has_dont_replicate() and 
+      reference.replication_options().dont_replicate())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+template<class T> inline bool is_replicated(const T*& ptr)
+{
+  if (ptr and
+      ptr->has_replication_options() and 
+      ptr->replication_options().has_dont_replicate() and 
+      ptr->replication_options().dont_replicate())
+  {
+    return false;
+  }
+
+  return true;
+}
+
 #if 0
 std::ostream& operator<<(std::ostream& output, const message::Transaction &message);
 std::ostream& operator<<(std::ostream& output, const message::Table &message);

=== modified file 'drizzled/message/schema.h'
--- drizzled/message/schema.h	2011-02-16 05:29:28 +0000
+++ drizzled/message/schema.h	2011-02-22 04:19:44 +0000
@@ -31,6 +31,7 @@
 namespace message {
 namespace schema {
 
+typedef message::Schema value_type;
 typedef boost::shared_ptr <message::Schema> shared_ptr;
 typedef const message::Schema const_reference;
 

=== modified file 'drizzled/plugin/schema_engine.cc'
--- drizzled/plugin/schema_engine.cc	2011-02-17 10:09:00 +0000
+++ drizzled/plugin/schema_engine.cc	2011-02-22 04:19:44 +0000
@@ -86,7 +86,8 @@
 */
 message::schema::shared_ptr StorageEngine::getSchemaDefinition(const drizzled::identifier::Table &identifier)
 {
-  return StorageEngine::getSchemaDefinition(identifier);
+  identifier::Schema schema_identifier= identifier;
+  return StorageEngine::getSchemaDefinition(schema_identifier);
 }
 
 message::schema::shared_ptr StorageEngine::getSchemaDefinition(const identifier::Schema &identifier)

=== modified file 'drizzled/table/concurrent.cc'
--- drizzled/table/concurrent.cc	2011-02-17 00:14:13 +0000
+++ drizzled/table/concurrent.cc	2011-02-22 04:19:44 +0000
@@ -129,9 +129,7 @@
 
   safe_mutex_assert_owner(table::Cache::singleton().mutex().native_handle());
 retry:
-  if (not (share= table::instance::Shared::make_shared(session,
-                                                       identifier,
-                                                       error)))
+  if (not (share= table::instance::Shared::make_shared(session, identifier, error)))
   {
     return 1;
   }

=== modified file 'drizzled/table/instance/base.h'
--- drizzled/table/instance/base.h	2011-02-17 10:09:00 +0000
+++ drizzled/table/instance/base.h	2011-02-22 04:19:44 +0000
@@ -721,7 +721,7 @@
 public:
   bool parse_table_proto(Session& session, message::Table &table);
 
-  virtual bool replicate() const
+  virtual bool is_replicated() const
   {
     return false;
   }

=== modified file 'drizzled/table/instance/shared.cc'
--- drizzled/table/instance/shared.cc	2011-02-17 00:14:13 +0000
+++ drizzled/table/instance/shared.cc	2011-02-22 04:19:44 +0000
@@ -20,9 +20,12 @@
 
 #include <config.h>
 
-#include <drizzled/table/instance/shared.h>
 #include <drizzled/definition/cache.h>
+#include <drizzled/error.h>
+#include <drizzled/message/schema.h>
 #include <drizzled/plugin/event_observer.h>
+#include <drizzled/table/instance/shared.h>
+#include <drizzled/plugin/storage_engine.h>
 
 namespace drizzled
 {
@@ -41,12 +44,33 @@
 {
 }
 
+Shared::Shared(const identifier::Table &identifier,
+               message::schema::shared_ptr schema_message) :
+  TableShare(message::Table::STANDARD, identifier, NULL, 0),
+  _schema(schema_message),
+  event_observers(NULL)
+{
+}
+
 Shared::Shared(const identifier::Table &identifier) :
   TableShare(identifier, identifier.getKey()),
   event_observers(NULL)
 {
 }
 
+bool Shared::is_replicated() const
+{
+  if (_schema)
+  {
+    if (not message::is_replicated(*_schema))
+      return false;
+  }
+
+  assert(getTableMessage());
+  return message::is_replicated(*getTableMessage());
+}
+
+
 Shared::shared_ptr Shared::foundTableShare(Shared::shared_ptr share)
 {
   /*
@@ -102,9 +126,17 @@
   /* Read table definition from cache */
   if ((share= definition::Cache::singleton().find(identifier.getKey())))
     return foundTableShare(share);
-
-  share.reset(new Shared(message::Table::STANDARD, identifier));
   
+  drizzled::message::schema::shared_ptr schema_message_ptr= plugin::StorageEngine::getSchemaDefinition(identifier);
+
+  if (not schema_message_ptr)
+  {
+    drizzled::my_error(ER_SCHEMA_DOES_NOT_EXIST, identifier);
+    return Shared::shared_ptr();
+  }
+
+  share.reset(new Shared(identifier, schema_message_ptr));
+
   if (share->open_table_def(*session, identifier))
   {
     in_error= share->error;
@@ -118,7 +150,10 @@
   bool ret= definition::Cache::singleton().insert(identifier.getKey(), share);
 
   if (not ret)
+  {
+    drizzled::my_error(ER_UNKNOWN_ERROR);
     return Shared::shared_ptr();
+  }
 
   return share;
 }

=== modified file 'drizzled/table/instance/shared.h'
--- drizzled/table/instance/shared.h	2011-02-16 05:29:28 +0000
+++ drizzled/table/instance/shared.h	2011-02-22 04:19:44 +0000
@@ -56,6 +56,8 @@
          const identifier::Table &identifier,
          char *path_arg= NULL, uint32_t path_length_arg= 0); // Shares for cache
 
+  Shared(const identifier::Table &identifier, message::schema::shared_ptr schema_message);
+
   Shared(const identifier::Table &identifier); // Used by placeholder
 
   ~Shared();
@@ -87,16 +89,11 @@
     event_observers= observers;
   }
 
-  virtual bool replicate() const
-  {
-    if (getTableMessage()->options().has_dont_replicate() and getTableMessage()->options().dont_replicate())
-      return false;
-
-    return true;
-  }
+  virtual bool is_replicated() const;
 
 private:
   boost::mutex mutex;                /* For locking the share  */
+  drizzled::message::schema::shared_ptr _schema;
 
   /* 
     event_observers is a class containing all the event plugins that have 

=== modified file 'drizzled/transaction_services.cc'
--- drizzled/transaction_services.cc	2011-02-17 10:09:00 +0000
+++ drizzled/transaction_services.cc	2011-02-22 04:19:44 +0000
@@ -1385,7 +1385,7 @@
   if (! replication_services.isActive())
     return false;
 
-  if (not table.getShare()->replicate())
+  if (not table.getShare()->is_replicated())
     return false;
 
   /**
@@ -1593,7 +1593,7 @@
   if (! replication_services.isActive())
     return;
 
-  if (not table.getShare()->replicate())
+  if (not table.getShare()->is_replicated())
     return;
 
   uint32_t next_segment_id= 1;
@@ -1855,7 +1855,7 @@
   if (! replication_services.isActive())
     return;
 
-  if (not table.getShare()->replicate())
+  if (not table.getShare()->is_replicated())
     return;
 
   uint32_t next_segment_id= 1;
@@ -1911,10 +1911,10 @@
                                       const message::Table &table)
 {
   ReplicationServices &replication_services= ReplicationServices::singleton();
-  if (! replication_services.isActive())
+  if (not replication_services.isActive())
     return;
 
-  if (table.has_options() and table.options().has_dont_replicate() and table.options().dont_replicate())
+  if (not message::is_replicated(table))
     return;
 
   message::Transaction *transaction= getActiveTransactionMessage(session);
@@ -1947,7 +1947,7 @@
   if (! replication_services.isActive())
     return;
 
-  if (schema.has_replication_options() and schema.replication_options().has_dont_replicate() and schema.replication_options().dont_replicate())
+  if (not message::is_replicated(schema))
     return;
 
   message::Transaction *transaction= getActiveTransactionMessage(session);
@@ -1978,10 +1978,10 @@
                                      message::schema::const_reference schema)
 {
   ReplicationServices &replication_services= ReplicationServices::singleton();
-  if (! replication_services.isActive())
+  if (not replication_services.isActive())
     return;
 
-  if (schema.has_replication_options() and schema.replication_options().has_dont_replicate() and schema.replication_options().dont_replicate())
+  if (not message::is_replicated(schema))
     return;
 
   message::Transaction *transaction= getActiveTransactionMessage(session);
@@ -2014,7 +2014,7 @@
   if (! replication_services.isActive())
     return;
 
-  if (old_schema.has_replication_options() and old_schema.replication_options().has_dont_replicate() and old_schema.replication_options().dont_replicate())
+  if (not message::is_replicated(old_schema))
     return;
 
   message::Transaction *transaction= getActiveTransactionMessage(session);
@@ -2052,7 +2052,7 @@
   if (! replication_services.isActive())
     return;
 
-  if (table.has_options() and table.options().has_dont_replicate() and table.options().dont_replicate())
+  if (not message::is_replicated(table))
     return;
 
   message::Transaction *transaction= getActiveTransactionMessage(session);
@@ -2089,7 +2089,7 @@
   if (! replication_services.isActive())
     return;
 
-  if (not table.getShare()->replicate())
+  if (not table.getShare()->is_replicated())
     return;
 
   message::Transaction *transaction= getActiveTransactionMessage(session);

=== modified file 'plugin/mysql_protocol/net_serv.cc'
--- plugin/mysql_protocol/net_serv.cc	2011-02-17 00:14:13 +0000
+++ plugin/mysql_protocol/net_serv.cc	2011-02-22 04:19:44 +0000
@@ -97,7 +97,9 @@
 {
   Vio *vio_tmp= new Vio(sock);
   if (vio_tmp == NULL)
+  {
     return true;
+  }
   else
     if (drizzleclient_net_init(net, vio_tmp, buffer_length))
     {
@@ -105,7 +107,9 @@
        * NET object.
        */
       if (vio_tmp && (net->vio != vio_tmp))
+      {
         delete vio_tmp;
+      }
       else
       {
         (void) shutdown(sock, SHUT_RDWR);
@@ -126,11 +130,7 @@
 
 void drizzleclient_net_close(NET *net)
 {
-  if (net->vio != NULL)
-  {
-    delete net->vio;
-    net->vio= 0;
-  }
+  drizzled::safe_delete(net->vio);
 }
 
 bool drizzleclient_net_peer_addr(NET *net, char *buf, uint16_t *port, size_t buflen)
@@ -857,7 +857,9 @@
         }
       }
       else
+      {
         complen= packet_len;
+      }
 
     }
     buf_length+= complen;

=== modified file 'tests/r/drizzledump_restore.result'
--- tests/r/drizzledump_restore.result	2011-02-04 08:47:29 +0000
+++ tests/r/drizzledump_restore.result	2011-02-22 04:19:44 +0000
@@ -93,9 +93,9 @@
 DROP DATABASE drizzledump_test;
 Ensure we don't have those tables (verify we restored something)
 SELECT * FROM test.t1;
-ERROR 42S02: Unknown table 'test.t1'
+Got one of the listed errors
 SELECT * FROM drizzledump_test.t1;
-ERROR 42S02: Unknown table 'drizzledump_test.t1'
+Got one of the listed errors
 Restoring from dumpfile
 USE test;
 SELECT * FROM t1;

=== modified file 'tests/t/drizzledump_restore.test'
--- tests/t/drizzledump_restore.test	2011-02-04 04:21:02 +0000
+++ tests/t/drizzledump_restore.test	2011-02-22 04:19:44 +0000
@@ -114,9 +114,9 @@
 DROP DATABASE drizzledump_test;
 
 --echo Ensure we don't have those tables (verify we restored something)
---ERROR ER_TABLE_UNKNOWN
+--ERROR ER_TABLE_UNKNOWN,ER_SCHEMA_DOES_NOT_EXIST
 SELECT * FROM test.t1;
---ERROR ER_TABLE_UNKNOWN
+--ERROR ER_TABLE_UNKNOWN,ER_SCHEMA_DOES_NOT_EXIST
 SELECT * FROM drizzledump_test.t1;
 
 --echo Restoring from dumpfile

=== modified file 'tests/t/errors.test'
--- tests/t/errors.test	2011-02-04 04:21:02 +0000
+++ tests/t/errors.test	2011-02-22 04:19:44 +0000
@@ -18,7 +18,7 @@
 select count(not_existing_database.t1) from t1;
 --error ER_BAD_FIELD_ERROR
 select count(not_existing_database.t1.a) from t1;
---error ER_DBACCESS_DENIED_ERROR, ER_TABLE_UNKNOWN
+--error ER_DBACCESS_DENIED_ERROR, ER_TABLE_UNKNOWN,ER_SCHEMA_DOES_NOT_EXIST
 select count(not_existing_database.t1.a) from not_existing_database.t1;
 --error ER_BAD_FIELD_ERROR
 select 1 from t1 order by 2;

